@@ -1,4 +1,4 @@
 #!/bin/sh
 
 echo "Run trigger (triggered by $TRIGGER_PATH)"
-echo $CONTENT_FOR_FILE > triggered.txt
+echo "$TRIGGER_PATH - $CONTENT_FOR_FILE" > triggered.txt
